@@ -22,6 +22,9 @@ import os
 import re
 import locale
 import glob
+import StringIO
+import zlib
+import gzip
 
 
 month_names = {"Jan": 1, "Feb": 2, "Mar": 3, "Apr": 4, "May": 5, "Jun": 6,
@@ -237,6 +240,36 @@ def get_page_base(page, html):
     return page.geturl()
 
 
+def get_page_data(url, **kwargs):
+    if not "headers" in kwargs:
+        kwargs["headers"] = {}
+    kwargs["headers"]["Accept-Encoding"] = "gzip,deflate"
+    page = urlopener.open(urllib2.Request(url=quote_url_path(url), **kwargs))
+    content = page.read()
+    data = content
+    if "Content-Encoding" in page.info():
+        enc = page.info()["Content-Encoding"]
+        if enc == "deflate":
+            data = zlib.decompress(content)
+        elif enc == "gzip":
+            sio = StringIO.StringIO(content)
+            try:
+                gzf = gzip.GzipFile(fileobj = sio)
+                try:
+                    data = gzf.read()
+                finally:
+                    gzf.close()
+            finally:
+                sio.close()
+    return (page, data)
+
+
+def get_body_or_html(html):
+    if html and html.body:
+        return html.body
+    return html
+
+
 refresh_reqex = re.compile("refresh", re.IGNORECASE)
 
 
@@ -406,7 +439,7 @@ class Item:
         self.__callback = callback
         self.__attrs_for_fix = [("a", "href"), ("iframe", "src"), ("form", "action")]
         self.__attrs_for_cache = [("script", "src"), ("img", "src"), ("input", "src")]
-        self.__tags_for_removal = ["object", "applet", "embed"]
+        self.__tags_for_removal = ["head", "object", "applet", "embed"]
         self.__allow_scripts = allow_scripts
         if not self.__allow_scripts:
             self.__tags_for_removal.append("script")
@@ -463,10 +496,10 @@ class Item:
         kwargs are passed to Request object constructor.
         """
         self.__report("downloading", url)
-        page = urlopener.open(urllib2.Request(url=quote_url_path(url), **kwargs))
+        (page, data) = get_page_data(url, **kwargs)
         try:
             self.__report("parsing", url)
-            html = BeautifulSoup(page, fromEncoding = get_page_encoding(page))
+            html = BeautifulSoup(data, fromEncoding = get_page_encoding(page))
             base = get_page_base(page, html)
             url = page.geturl()
         finally:
@@ -514,7 +547,7 @@ class Item:
                 if a:
                     url = urljoin(base, a["href"])
                     (new_html, new_base, real_url) = self.__get_page_html(url, headers={"Referer": referer})
-                    return (new_html, new_base, new_html.body)
+                    return (new_html, new_base, get_body_or_html(new_html))
         except Exception, ex:
             self.__report("error", ex)
         return (html, base, None)
@@ -539,13 +572,14 @@ class Item:
             (html, self.__base, sp) = self.__find_single_page(html, self.__base, real_url)
         if not sp and not self.__tag and self.__next_page_keywords:
             self.__next_page_a = self.__cache_next_page(html, self.__base)
+        body = get_body_or_html(html)
         if not self.__reformatter_url:
             if self.__content_kwargs:
-                self.__tag = html.body.find(**self.__content_kwargs)
+                self.__tag = body.find(**self.__content_kwargs)
             if not self.__tag:
-                self.__tag = self.__find_the_tag(html.body)
+                self.__tag = self.__find_the_tag(body)
         if not self.__tag:
-            self.__tag = html.body
+            self.__tag = body
         title = html.find("title")
         if title:
             self.title = title.string.strip()
@@ -914,11 +948,11 @@ class Feed:
         div = None
         try:
             self.__report("downloading", self.__url, 1)
-            page = urlopener.open(quote_url_path(self.__url))
+            (page, data) = get_page_data(self.__url)
             try:
                 self._real_url = page.geturl()
                 self.__report("parsing", self.__url, 10)
-                xml = BeautifulStoneSoup(page, markupMassage = massage)
+                xml = BeautifulStoneSoup(data, markupMassage = massage)
             finally:
                 page.close()
             if not self.__title:
