@@ -20,7 +20,7 @@ import shutil
 import sys
 from BeautifulSoup import BeautifulStoneSoup
 
-version = "0.7.4"
+version = "0.7.5"
 feed_template_default = """
 <html>
     <head>
@@ -36,13 +36,6 @@ custom_style = '<link rel="stylesheet" href="%(filename)s" type="text/css" />'
 
 gtk.gdk.threads_init()
 
-#This is to be able to start Feed Circuit on PC
-try:
-    import osso
-    osso_context = osso.Context("org.maemo.feedcircuit", version, False)
-except ImportError:
-    pass
-
 #This is also to be able to start Feed Circuit on PC
 try:
     import conic
@@ -93,6 +86,14 @@ except ImportError:
         return [("test1id", "test1"), ("test2id", "test2")]
 
 
+def init_osso_context():
+    try:
+        import osso
+        osso_context = osso.Context("org.maemo.feedcircuit", version, False)
+    except ImportError:
+        pass
+
+
 def show_file_chooser(title, parent, action, filename = None):
     try:
         dlg = hildon.FileChooserDialog(parent = parent, action = action)
@@ -426,6 +427,7 @@ class FeedListModel(gtk.GenericTreeModel):
         self.connection_id = parser.get_default("global", "connection id", "")
         self.autorefresh_checked = parser.getboolean_default("global", "autorefresh checked", False)
         self.is_interval = parser.getboolean_default("global", "is interval", False)
+        self.browser = parser.get_default("global", "browser", "")
         for section in parser.sections():
             if section != "global":
                 feed_config = FeedConfig(
@@ -472,6 +474,7 @@ class FeedListModel(gtk.GenericTreeModel):
             parser.set("global", "connection id", self.connection_id)
             parser.set("global", "autorefresh checked", str(self.autorefresh_checked))
             parser.set("global", "is interval", str(self.is_interval))
+            parser.set("global", "browser", self.browser)
             i = 0
             for feed_config in self.list:
                 parser.add_section(feed_config.id)
@@ -1001,6 +1004,9 @@ class Program(hildon.Program):
         if not os.path.exists(self.__model.get_config_file_name()):
             self.import_opml()
 
+        if self.__model.browser:
+            webbrowser.register("FeedCircuitCustom", None, webbrowser.BackgroundBrowser(self.__model.browser.split()))
+
         menu = gtk.Menu()
         self.__toolbar = gtk.Toolbar()
         self.__toolbar.set_style(gtk.TOOLBAR_ICONS)
@@ -1090,6 +1096,8 @@ class Program(hildon.Program):
         self.__timer_id = 0
         self.schedule_next_update()
 
+        gobject.idle_add(init_osso_context)
+
 
     def append_action(self, menu, toolbar, title, stock, callback):
         if stock:
@@ -1175,13 +1183,20 @@ class Program(hildon.Program):
                 (delta.days * 24 * 3600 + delta.seconds) * 1000, self.auto_refresh)
 
 
+    def open_url(self, url, new_win):
+        if self.__model.browser:
+            webbrowser.get("FeedCircuitCustom").open("file://" + url, new_win)
+        else:
+            webbrowser.open(url, new_win)
+
+
     def open_feed(self, feed_config):
         path = os.path.join(self.__model.cache_path, feed_config.get_filename())
         if os.path.exists(path):
             new_win = 0
             if self.__model.use_new_window:
                 new_win = 2
-            webbrowser.open(path, new_win)
+            self.open_url(path, new_win)
             feed_config.message_count = 0
             self.__model.update(feed_config.id)
         else:
